# SSL Metrics

> Helper package that will install all `ssl-metrics` packages at once

[![Publish to PyPi](https://github.com/SoftwareSystemsLaboratory/ssl-metrics/actions/workflows/pypi.yml/badge.svg)](https://github.com/SoftwareSystemsLaboratory/ssl-metrics/actions/workflows/pypi.yml)

## Table of Contents

- [SSL Metrics](#ssl-metrics)
  - [Table of Contents](#table-of-contents)
  - [About](#about)
  - [Included Projects](#included-projects)
  - [How to Install](#how-to-install)
    - [From pip](#from-pip)

## About

This project is simply a wrapper/ helper program that installs all of the other `ssl-metrics` projects.

## Included Projects

- [ssl-metrics-github-issues](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-github-issues)
- [ssl-metrics-git-commits-loc](https://github.com/SoftwareSystemsLaboratory/ssl-metrics-git-commits-loc)

## How to Install

### From pip

1. Install `Python 3.9.6 +`
2. (Recommended) Create a *virtual environment* with `python3.9 -m venv env` and *activate* it
3. Run `pip install ssl-metrics`
4. To run any of the installed packages, see their specific documentation pages for more information
